/*	Debug.cpp
*
*	Debugging stuff!
*
*	#define these as desired:
*		DEBUG_COMM_TYPE     class to use for serial output
*		DEBUG_COMM          variable name to use for serial output
*		DEBUG_LCD_TYPE      class to use for LCD output
*		DEBUG_LCD           variable name to use for LCD output
*	Output will go only to what's defined.
*
*	Revisions:
*		07-05-06	version 1 in master library
*		09-25-06	added DEBUG_COMM_TYPE and DEBUG_LCD_TYPE
*		09-28-06	Log only to comm, inline function
*		04-18-07	header comments for DEBUG_COMM/LCD[_TYPE]
*
*	Written by Cathy Saxton
*	robotics@idleloop.com
*/

#include <stdio.h>
#include "Util.h"
#include "Debug.h"

#ifdef DEBUG_COMM
/* transmit error messages on the serial connection */
#include "Comm.h"
extern DEBUG_COMM_TYPE DEBUG_COMM;
#endif

#ifdef DEBUG_LCD
/* show error messages on the second line of the LCD */
#include "LCD.h"
extern DEBUG_LCD_TYPE DEBUG_LCD;
#endif

void AssertProc(const char *pszFile, int line)
{
#if defined(DEBUG_COMM) || defined(DEBUG_LCD)
	char sz[32];
#endif

#ifdef DEBUG_COMM
	snprintf(sz, sizeof(sz), "Assert: %d in %s\r\n", line, pszFile);
	DEBUG_COMM.Print(sz);
#endif // DEBUG_COMM

#ifdef DEBUG_LCD
	/* show error messages on the second line of the LCD */
	snprintf(sz, sizeof(sz), "! %d %s", line, pszFile);
#ifdef DEBUG_LCD_FN
	DEBUG_LCD.DEBUG_LCD_FN(sz);
#else
	DEBUG_LCD.Print(sz, 2);
#endif
#endif // DEBUG_LCD
}
