/*	Debug.h
*
*	Debugging stuff!
*
*	#define these as desired:
*		DEBUG_COMM_TYPE     class to use for serial output
*		DEBUG_COMM          variable name to use for serial output
*		DEBUG_LCD_TYPE      class to use for LCD output
*		DEBUG_LCD           variable name to use for LCD output
*	Output will go only to what's defined.
*
*	Revisions:
*		07-05-06	version 1 in master library
*		09-28-06	Log only to comm, inline function
*		04-18-07	header comments for DEBUG_COMM/LCD[_TYPE]
*		05-15-10	client now responsible for debug/log implementation
*
*	Written by Cathy Saxton
*	robotics@idleloop.com
*/

#pragma once

#ifdef DEBUG

void AssertProc(const char *pszFile, int line);

#define Assert(f)			{ if (!(f)) AssertProc(__FILE__, __LINE__); }
#define Debug(x)			x

void LogProc(const char *psz, ...);
void LogPgmProc(const char *psz, ...);
#define Log(lgt, psz, ...)		{ if (lgt) LogProc(psz, ## __VA_ARGS__); }
/* output string from progmem */
#define LogPgm(lgt, psz, ...)	{ if (lgt) LogPgmProc(psz, ## __VA_ARGS__); }

#else

#define Assert(f)			{ }
#define Debug(x)
#define Log(lgt, psz)		{ }
#define LogPgm(lgt, psz)	{ }

#endif

/* convenient way to disable a Log statement */
#define LogX(lgt, psz) { }
